%% This is the matlab scripts folder used in the following paper:

% Tianyu Qiu, Wending Liao, Yihui Huang, Jinyu Wu, Di Guo, Dongbao Liu, Xin Wang, Jan-Feng Cai, Bingwen Hu, Xiaobo Qu*,
% An automatic denoising method for NMR spectroscopy based on low-rank Hankel model, IEEE Transactions on Instrumentation and Measurement, 70: 1-12, 2021.
%% 
% We make our software routines available for non-profit scientific research, enabling others researchers to understand, reproduce and extend our work. All rights are reserved by the authors. Unauthorized use of the routines for profit-oriented activities is expressively prohibited.
% Author: Tianyu Qiu.
% Created date: 2021.04
% Verified date: 2023.02
% Corresponding Author: Xiaobo Qu
% Email: quxiaobo@xmu.edu.cn

% If you use this Comprehensive codes, please cite the papers below:

% [1] Tianyu Qiu, Wending Liao, Yihui Huang, Jinyu Wu, Di Guo, Dongbao Liu, Xin Wang, Jan-Feng Cai, Bingwen Hu, Xiaobo Qu*, 
% An automatic denoising method for NMR spectroscopy based on low-rank Hankel model, IEEE Transactions on Instrumentation and Measurement, 70: 1-12, 2021.
%%
clear;
close all;
%%
currentFolder = pwd;
addpath(genpath(currentFolder));
%% Load real NMR data
load Cho_Cr_CitMg_2.mat
%%
FID = signal;
FID = FID./max(abs(FID)); % Normalization
%% Add Gaussian noise
noiseSTD = 0.020;  % The standard deviation of noise
noise = noiseSTD*(randn(size(FID))+1i*randn(size(FID))); % Generate Gaussian noise
FID_noisy = FID + noise;
%% Denoising by CHORD
FID_rec_Chord = Chord_Integ(FID_noisy);
%% Presented denoised spectrum
spec_rec_Chord = real(fft2c(FID_rec_Chord)*exp(1i*2*pi*0.26)); % FFT & P0 correction
spec_rec_Chord_norm = spec_rec_Chord./max(spec_rec_Chord(:)); % Normalization in the frequency domain
figure;plot(spec_rec_Chord_norm);ylim([-0.1,1]),xlim([0 numel(spec_rec_Chord_norm)]);title('CHORD');grid on;

